setGlobalCacheFolderCustomPath static method

Future<bool?> setGlobalCacheFolderCustomPath({
  1. String? androidAbsolutePath,
  2. String? iOSAbsolutePath,
})

Set the absolute path of the player resource cache directory. This method will override each other with setGlobalCacheFolderPath(String postfixPath), and you only need to call one of them.

@param androidAbsolutePath Android side absolute path iOSAbsolutePath iOS side absolute path @return true if the setting is successful, false otherwise

Implementation

static Future<bool?> setGlobalCacheFolderCustomPath({String? androidAbsolutePath, String? iOSAbsolutePath}) async {
  return await _pluginChannel.invoke<bool>('setGlobalCacheFolderCustomPath', {
    'androidAbsolutePath': androidAbsolutePath,
    'iOSAbsolutePath': iOSAbsolutePath,
  });
}