setGlobalEnv static method

Future<int?> setGlobalEnv(
  1. String envConfig
)

Setting the environment for accessing the LiteAV SDK. Tencent Cloud has deployed environments in various regions around the world, and different access points need to be accessed according to local policies and regulations.

@param envConfig The environment to be accessed. The SDK defaults to the official environment. @return 0: success; others: error @note Customers targeting the Chinese mainland market should not call this interface. If the target market is overseas users, please contact us through technical support to learn about the configuration method of env_config to ensure that the App complies with GDPR standards.

Implementation

static Future<int?> setGlobalEnv(String envConfig) async {
  return await _pluginChannel.invoke<int>('setGlobalEnv', {'value': envConfig});
}