setGlobalMaxCacheSize static method

Future<void> setGlobalMaxCacheSize(
  1. int size
)

Setting the maximum cache size for the playback engine. After setting, files in the Cache directory will be automatically cleaned up based on the set value. @param size Maximum cache size (unit: MB).

Implementation

static Future<void> setGlobalMaxCacheSize(int size) async {
  await _pluginChannel.invoke<void>('setGlobalMaxCacheSize', {'value': size});
}