setLicenseFlexibleValid static method

Future<void> setLicenseFlexibleValid(
  1. bool enabled
)

Enable flexible verification of player License; once enabled, the verification will pass by default for the first two times after the player is launched for the first time.

Implementation

static Future<void> setLicenseFlexibleValid(bool enabled) async {
  await _pluginChannel.invoke<void>('setLicenseFlexibleValid', {'value': enabled});
}