startVideoOrientationService static method
Starts listening for device rotation direction. After it is turned on, if the device's auto-rotation is turned on, the player will automatically rotate the video direction based on the current device orientation.
This interface is currently only applicable to the Android side, and the iOS side will automatically enable this feature
Before calling this interface, please be sure to inform the user of the privacy risks. If necessary, confirm whether you have permission to access the rotation sensor. @return true: success false: failure, due to premature enabling, waiting for context initialization, failure to obtain sensor, etc.Implementation
static Future<bool?> startVideoOrientationService() async {
return await _pluginChannel.invoke<bool>('startVideoOrientationService');
}