TXSubtitleRenderModel class
Properties
-
canvasHeight
↔ int?
-
canvasHeight not support on Flutter platform
getter/setter pair
-
canvasWidth
↔ int?
-
canvasWidth not support on Flutter platform
getter/setter pair
-
endMargin
↔ double?
-
endMargin not support on Flutter platform
getter/setter pair
-
familyName
↔ String?
-
familyName not support on Flutter platform
getter/setter pair
-
fontColor
↔ int?
-
Font color, ARGB format. If not set, the default is white opaque (0xFFFFFFFF).
getter/setter pair
-
fontScale
↔ double?
-
fontScale not support on Flutter platform
getter/setter pair
-
fontSize
↔ double?
-
fontSize.
getter/setter pair
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
isBondFontStyle
↔ bool?
-
Whether it is bold, the default is normal font.
getter/setter pair
-
lineSpace
↔ double?
-
lineSpace not support on Flutter platform
getter/setter pair
-
outlineColor
↔ int?
-
Stroke color, ARGB format. If not set, the default is black opaque (0xFF000000).
getter/setter pair
-
outlineWidth
↔ double?
-
Stroke width. If not set, the default stroke width will be used internally.
getter/setter pair
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
startMargin
↔ double?
-
startMargin not support on Flutter platform
getter/setter pair
-
verticalMargin
↔ double?
-
verticalMargin not support on Flutter platform
getter/setter pair
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap()
→ Map<String, dynamic>
-
Serialize to a Map for MethodChannel transport.
-
toString()
→ String
-
A string representation of this object.
inherited