TXVodDownloadDataSource class
File ID storage.
Constructors
Properties
- appId ↔ int?
-
App ID corresponding to the downloaded file, required for file ID download.
getter/setter pair
- fileId ↔ String?
-
Downloaded file ID, required for fileId download.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- pSign ↔ String?
-
Encryption signature, required for encrypted video.
getter/setter pair
- quality ↔ int?
-
Quality ID, required for file ID download, converted through CommonUtils.getDownloadQualityBySize.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- token ↔ String?
-
Encryption token.
getter/setter pair
- userName ↔ String?
-
Account name, used to set the account name for URL download.
It is not recommended to set a string that is too long,
otherwise it may lead to unforeseen problems.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Kept for backward compatibility; delegates to toMap.
-
toMap(
) → Map< String, dynamic> - Serialize to a Map.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromMap(
Map map) → TXVodDownloadDataSource - Construct from a Map.