userName property

String? userName
getter/setter pair

Account name, used to set the account name for URL download. It is not recommended to set a string that is too long, otherwise it may lead to unforeseen problems.

Implementation

String? userName;