deselectTrack method

Future<void> deselectTrack(
  1. int trackIndex
)

This interface is only supported by the premium version of the player (Player_Premium), and you need to purchase the premium version of the player mobile license. Deselect a track. @param trackIndex track index, obtained from trackIndex of TXTrackInfo

Implementation

Future<void> deselectTrack(int trackIndex) async {
  if (_isNeedDisposed) return;
  await _initPlayer.future;
  await _mc!.invoke<void>('deselectTrack', {'value': trackIndex});
}