startVodPlay method
Starting from version 10.7, the method startPlay has been changed to startVodPlay for playing videos via a URL.
To play videos successfully, it is necessary to set the license by using the method SuperPlayerPlugin#setGlobalLicense.
Failure to set the license will result in video playback failure (a black screen).
Live streaming, short video, and video playback licenses can all be used. If you do not have any of the above licenses,
you can apply for a free trial license to play videos normallyQuickly apply for a free trial version Licence
(https://cloud.tencent.com/act/event/License).Official licenses can be purchased
(https://cloud.tencent.com/document/product/881/74588).
@param url video playback address @return whether the playback starts successfully
Implementation
Future<bool> startVodPlay(String url) async {
if (_isNeedDisposed) return false;
await _initPlayer.future;
_changeState(TXPlayerState.buffering);
printVersionInfo();
final result = await _mc!.invoke<bool>('startVodPlay', {'value': url});
return result ?? false;
}