startVodPlayWithParams method
Starting from version 10.7, the method "startPlayWithParams" has been changed to "startVodPlayWithParams" for playing videos using fileId.
To play the video successfully, you need to set the Licence using "SuperPlayerPlugin#setGlobalLicense" method before playing the video.
If you do not set the Licence, the video will not play (black screen). The Licence for live streaming,
short video, and video playback can all be used. If you have not obtained the Licence, you can apply for a free trial version here
(https://cloud.tencent.com/act/event/License) for normal playback. To use the official version, you need to purchase
(https://cloud.tencent.com/document/product/881/74588).
@param params see TXPlayInfoParams
Implementation
Future<void> startVodPlayWithParams(TXPlayInfoParams params) async {
if (_isNeedDisposed) return;
await _initPlayer.future;
_changeState(TXPlayerState.buffering);
printVersionInfo();
await _mc!.invoke<void>('startVodPlayWithParams', params.toMap());
}