AITranscriberManager class abstract
Manager for AI real-time transcription and translation.
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addListener(
AITranscriberListener listener) → void - Add event listener for transcription events.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
pauseReceivingMessage(
) → void - Pause receiving transcription messages.
-
removeListener(
AITranscriberListener listener) → void - Remove event listener.
-
resumeReceivingMessage(
) → void - Resume receiving transcription messages.
-
startRealtimeTranscriber(
TranscriberParams params) → void - Start real-time transcription.
-
stopRealtimeTranscriber(
String transcriberRobotId) → void - Stop real-time transcription.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited