TXDeviceInfoStruct class

Inheritance
Implemented types
Available extensions

Constructors

TXDeviceInfoStruct()

Properties

address → Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
device_name ↔ Pointer<Char>
getter/setter pair
device_name_len ↔ int
getter/setter pair
device_pid ↔ Pointer<Char>
getter/setter pair
device_pid_len ↔ int
getter/setter pair
device_properties ↔ Pointer<Char>
getter/setter pair
device_properties_len ↔ int
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

create() → Pointer<TXDeviceInfoStruct>
Creates a struct view of bytes in typedData.
override
freeStruct(Pointer<TXDeviceInfoStruct> deviceInfoPointer) → dynamic
fromParams(TXDeviceInfo deviceInfo) → Pointer<TXDeviceInfoStruct>