V2TXLiveMixStreamStruct class

Inheritance
Implemented types
Available extensions

Constructors

V2TXLiveMixStreamStruct()

Properties

address → Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
hashCode → int
The hash code for this object.
no setterinherited
height ↔ int
getter/setter pair
input_type ↔ int
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stream_id ↔ Pointer<Char>
getter/setter pair
user_id ↔ Pointer<Char>
getter/setter pair
width ↔ int
getter/setter pair
x ↔ int
getter/setter pair
y ↔ int
getter/setter pair
z_order ↔ int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

convert(V2TXLiveMixStream mixStream) → Pointer<V2TXLiveMixStreamStruct>
freeStruct(Pointer<V2TXLiveMixStreamStruct> pointer) → void
释放结构体内存