V2TXLiveTranscodingConfigStruct class

Inheritance
Implemented types
Available extensions

Properties

address → Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
audio_bitrate ↔ int
getter/setter pair
audio_channels ↔ int
getter/setter pair
audio_sample_rate ↔ int
getter/setter pair
background_color ↔ int
getter/setter pair
background_image ↔ Pointer<Char>
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
mix_stream_size ↔ int
getter/setter pair
mix_streams_array ↔ Pointer<V2TXLiveMixStreamStruct>
getter/setter pair
output_stream_id ↔ Pointer<Char>
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
video_bitrate ↔ int
getter/setter pair
video_framerate ↔ int
getter/setter pair
video_gop ↔ int
getter/setter pair
video_height ↔ int
getter/setter pair
video_width ↔ int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited