TXDeviceManagerImpl class
- Inheritance
-
- Object
- TXDeviceManager
- TXDeviceManagerImpl
Constructors
- TXDeviceManagerImpl(TXDeviceManagerNativePointer nativePointer)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
destroy(
) → void -
enableCameraAutoFocus(
bool enabled) → int -
Enabling auto focus (for mobile OS)
override
-
enableCameraTorch(
bool enabled) → int -
Enabling/Disabling flash, i.e., the torch mode (for mobile OS)
override
-
enableFollowingDefaultAudioDevice(
TXMediaDeviceType type, bool enable) → int -
Set the Audio Device Used by SDK to Follow the System Default Device (for Desktop OS)
override
-
getApplicationMuteState(
) → int -
Querying whether the current process is muted in the volume mixer (for Windows)
override
-
getApplicationPlayVolume(
) → int -
Getting the volume of the current process in the volume mixer (for Windows)
override
-
getCameraZoomMaxRatio(
) → double -
Getting the maximum zoom ratio of the camera (for mobile OS)
override
-
getCurrentDevice(
TXMediaDeviceType type) → TXDeviceInfo -
Getting the device currently in use (for desktop OS)
override
-
getCurrentDeviceMute(
TXMediaDeviceType type) → bool -
Querying whether the current device is muted (for desktop OS)
override
-
getCurrentDeviceVolume(
TXMediaDeviceType type) → int -
Getting the Volume of the Current Device (for Desktop OS)
override
-
getDevicesList(
TXMediaDeviceType type) → List< TXDeviceInfo> -
Getting the Device List (for Desktop OS)
override
-
isAutoFocusEnabled(
) → bool -
Querying whether automatic face detection is supported (for mobile OS)
override
-
isFrontCamera(
) → bool -
Querying whether the front camera is being used
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setApplicationMuteState(
bool mute) → int -
Muting the current process in the volume mixer (for Windows)
override
-
setApplicationPlayVolume(
int volume) → int -
Setting the volume of the current process in the volume mixer (for Windows)
override
-
setAudioRoute(
TXAudioRoute route) → int -
Setting the Audio Route (for Mobile OS)
override
-
setCameraCaptureParam(
TXCameraCaptureParam params) → void -
Set camera acquisition preferences
override
-
setCameraFocusPosition(
double x, double y) → int -
Adjusting the Focus (for Mobile OS)
override
-
setCameraZoomRatio(
double ratio) → int -
Setting the Camera Zoom Ratio (for Mobile OS)
override
-
setCurrentDevice(
TXMediaDeviceType type, String deviceId) → int -
Setting the Device to Use (for Desktop OS)
override
-
setCurrentDeviceMute(
TXMediaDeviceType type, bool mute) → int -
Muting the current device (for desktop OS)
override
-
setCurrentDeviceVolume(
TXMediaDeviceType type, int volume) → int -
Setting the Volume of the Current Device (for Desktop OS)
override
-
setDeviceObserver(
TXDeviceObserver? observer) → int -
set onDeviceChanged callback
override
-
startCameraDeviceTest(
int viewId) → int -
Starting Camera Testing (for Desktop OS)
override
-
startMicDeviceTest(
int interval) → int -
Starting Mic Testing (for Desktop OS)
override
-
startMicDeviceTestAndPlayback(
int interval, bool playback) → int -
Starting Mic Testing (for Desktop OS)
override
-
startSpeakerDeviceTest(
String filePath) → int -
Starting Speaker Testing (for Desktop OS)
override
-
stopCameraDeviceTest(
) → void -
Ending camera testing (for desktop OS)
override
-
stopMicDeviceTest(
) → void -
Ending mic testing (for desktop OS)
override
-
stopSpeakerDeviceTest(
) → void -
Ending speaker testing (for desktop OS)
override
-
switchCamera(
bool frontCamera) → int -
Switching to the front/rear camera (for mobile OS)
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited