getCurrentDeviceVolume method

int getCurrentDeviceVolume(
  1. TXMediaDeviceType type
)
override

Getting the Volume of the Current Device (for Desktop OS)

This API is used to get the capturing volume of the mic or playback volume of the speaker, but not the volume of the camera.

Implementation

int getCurrentDeviceVolume(TXMediaDeviceType type) {
  if (_only_support_desktop) {
    return _deviceFFIBindings.get_current_device_volume(_nativePointer, type.value());
  } else {
    debugPrint("device-manager-api not support");
    return -1;
  }
}