removeAllIncludedShareWindow abstract method

void removeAllIncludedShareWindow()

Remove all windows from the inclusion list of screen sharing (for desktop systems only)

This API takes effect only if the type in TRTCScreenCaptureSourceInfo is specified as TRTCScreenCaptureSourceTypeWindow. That is, the feature of additionally including specified windows works only when a window is shared.

Implementation

void removeAllIncludedShareWindow();