TRTCAudioFrame class

Audio frame data

Annotations
  • @JsonSerializable.new(explicitToJson: true, includeIfNull: false)

Constructors

TRTCAudioFrame({TRTCAudioFrameFormat audioFormat = TRTCAudioFrameFormat.none, int length = 0, int sampleRate = 0, int channel = 0, int timestamp = 0, int extraDataLength = 0, Uint8List? data, Uint8List? extraData})
TRTCAudioFrame.fromJson(Map<String, dynamic> json)
factory
TRTCAudioFrame.fromJsonWithData(Map<String, dynamic> json, Uint8List audioData)
factory

Properties

audioFormat ↔ TRTCAudioFrameFormat
  • Field description: Audio frame format.
  • getter/setter pair
    channel ↔ int
  • Field description: Number of sound channels.
  • getter/setter pair
    data ↔ Uint8List
  • Field description: Audio data.
  • getter/setter pair
    extraData ↔ Uint8List
  • Field description: Extra data in audio frame. Message sent by remote users through onLocalProcessedAudioFrame that adds to audio frame will be callback through this field.
  • getter/setter pair
    extraDataLength ↔ int
  • Field description: Extra data length.
  • getter/setter pair
    hashCode → int
    The hash code for this object.
    no setterinherited
    length ↔ int
  • Field description: Audio data length.
  • getter/setter pair
    runtimeType → Type
    A representation of the runtime type of the object.
    no setterinherited
    sampleRate ↔ int
  • Field description: Sample rate.
  • getter/setter pair
    timestamp ↔ int
  • Field description: Timestamp in ms.
  • getter/setter pair

    Methods

    noSuchMethod(Invocation invocation) → dynamic
    Invoked when a nonexistent method or property is accessed.
    inherited
    toJson() → Map<String, dynamic>
    toString() → String
    A string representation of this object.
    inherited

    Operators

    operator ==(Object other) → bool
    The equality operator.
    inherited