TRTCLocalStatistics class

Local audio/video metrics

Annotations
  • @JsonSerializable.new(explicitToJson: true, includeIfNull: false)

Constructors

TRTCLocalStatistics({int width = -1, int height = -1, int frameRate = -1, int videoBitrate = -1, int audioSampleRate = -1, int audioBitrate = -1, TRTCVideoStreamType streamType = TRTCVideoStreamType.big, int audioCaptureState = -1})
TRTCLocalStatistics.fromJson(Map<String, dynamic> json)
factory

Properties

audioBitrate ↔ int
  • Field description: local audio bitrate in Kbps, i.e., how much audio data is generated per second
  • getter/setter pair
    audioCaptureState ↔ int
  • Field description: Audio equipment collection status(0:Normal;1:Long silence detected;2:Broken sound detected;3:Abnormal intermittent sound detected;)
  • getter/setter pair
    audioSampleRate ↔ int
  • Field description: local audio sample rate (Hz)
  • getter/setter pair
    frameRate ↔ int
  • Field description: local video frame rate in fps, i.e., how many video frames there are per second
  • getter/setter pair
    hashCode → int
    The hash code for this object.
    no setterinherited
    height ↔ int
  • Field description: local video height in px
  • getter/setter pair
    runtimeType → Type
    A representation of the runtime type of the object.
    no setterinherited
    streamType ↔ TRTCVideoStreamType
  • Field description: video stream type
  • getter/setter pair
    videoBitrate ↔ int
  • Field description: local video bitrate in Kbps, i.e., how much video data is generated per second
  • getter/setter pair
    width ↔ int
  • Field description: local video width in px
  • getter/setter pair

    Methods

    noSuchMethod(Invocation invocation) → dynamic
    Invoked when a nonexistent method or property is accessed.
    inherited
    toJson() → Map<String, dynamic>
    toString() → String
    A string representation of this object.
    inherited

    Operators

    operator ==(Object other) → bool
    The equality operator.
    inherited