TRTCScreenCaptureSourceInfo class

Target information for screen sharing (desktop only)

When users perform screen sharing, they can choose to capture the entire desktop or only the window of a certain program.

TRTCScreenCaptureSourceInfo is used to describe the information of the target to be shared, including ID, name, thumbnail, etc. The field information in this structure is read-only.

Constructors

TRTCScreenCaptureSourceInfo({TRTCScreenCaptureSourceType type = TRTCScreenCaptureSourceType.unknown, int viewId = 0, String sourceName = '', bool isMinimizeWindow = false, bool isMainScreen = false, int x = 0, int y = 0, int width = 0, int height = 0, TRTCImageBuffer? thumbBGRA, TRTCImageBuffer? iconBGRA})

Properties

hashCode → int
The hash code for this object.
no setterinherited
height ↔ int
  • Screen/window height, unit: pixels.
  • getter/setter pair
    iconBGRA ↔ TRTCImageBuffer
  • A icon image of the share window.
  • getter/setter pair
    isMainScreen ↔ bool
  • Whether it is the main display (applicable to multiple monitors).
  • getter/setter pair
    isMinimizeWindow ↔ bool
  • Whether the window is minimized.
  • getter/setter pair
    runtimeType → Type
    A representation of the runtime type of the object.
    no setterinherited
    sourceName ↔ String
  • Collection source name (encoded in UTF8).
  • getter/setter pair
    thumbBGRA ↔ TRTCImageBuffer
  • A thumbnail image of the share window.
  • getter/setter pair
    type ↔ TRTCScreenCaptureSourceType
  • Collection source type (share the entire screen? Or share a window?).
  • getter/setter pair
    viewId ↔ int
  • The ID of the collection source.
  • For windows, this field represents the ID of the window; for screens, this field represents the ID of the monitor.
  • getter/setter pair
    width ↔ int
  • Screen/window width, unit: pixels.
  • getter/setter pair
    x ↔ int
  • Screen/window x coordinate, unit: pixel.
  • getter/setter pair
    y ↔ int
  • Screen/window y coordinate, unit: pixel.
  • getter/setter pair

    Methods

    noSuchMethod(Invocation invocation) → dynamic
    Invoked when a nonexistent method or property is accessed.
    inherited
    toString() → String
    A string representation of this object.
    inherited

    Operators

    operator ==(Object other) → bool
    The equality operator.
    inherited