TXDeviceManager class abstract

Implementers

Constructors

TXDeviceManager()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

enableCameraAutoFocus(bool enabled) → int
Enabling auto focus (for mobile OS)
enableCameraTorch(bool enabled) → int
Enabling/Disabling flash, i.e., the torch mode (for mobile OS)
enableFollowingDefaultAudioDevice(TXMediaDeviceType type, bool enable) → int
Set the Audio Device Used by SDK to Follow the System Default Device (for Desktop OS)
getApplicationMuteState() → int
Querying whether the current process is muted in the volume mixer (for Windows)
getApplicationPlayVolume() → int
Getting the volume of the current process in the volume mixer (for Windows)
getCameraZoomMaxRatio() → double
Getting the maximum zoom ratio of the camera (for mobile OS)
getCurrentDevice(TXMediaDeviceType type) → TXDeviceInfo
Getting the device currently in use (for desktop OS)
getCurrentDeviceMute(TXMediaDeviceType type) → bool
Querying whether the current device is muted (for desktop OS)
getCurrentDeviceVolume(TXMediaDeviceType type) → int
Getting the Volume of the Current Device (for Desktop OS)
getDevicesList(TXMediaDeviceType type) → List<TXDeviceInfo>
Getting the Device List (for Desktop OS)
isAutoFocusEnabled() → bool
Querying whether automatic face detection is supported (for mobile OS)
isFrontCamera() → bool
Querying whether the front camera is being used
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setApplicationMuteState(bool mute) → int
Muting the current process in the volume mixer (for Windows)
setApplicationPlayVolume(int volume) → int
Setting the volume of the current process in the volume mixer (for Windows)
setAudioRoute(TXAudioRoute route) → int
Setting the Audio Route (for Mobile OS)
setCameraCaptureParam(TXCameraCaptureParam params) → void
Set camera acquisition preferences
setCameraFocusPosition(double x, double y) → int
Adjusting the Focus (for Mobile OS)
setCameraZoomRatio(double ratio) → int
Setting the Camera Zoom Ratio (for Mobile OS)
setCurrentDevice(TXMediaDeviceType type, String deviceId) → int
Setting the Device to Use (for Desktop OS)
setCurrentDeviceMute(TXMediaDeviceType type, bool mute) → int
Muting the current device (for desktop OS)
setCurrentDeviceVolume(TXMediaDeviceType type, int volume) → int
Setting the Volume of the Current Device (for Desktop OS)
setDeviceObserver(TXDeviceObserver? observer) → int
set onDeviceChanged callback
startCameraDeviceTest(int viewId) → int
Starting Camera Testing (for Desktop OS)
startMicDeviceTest(int interval) → int
Starting Mic Testing (for Desktop OS)
startMicDeviceTestAndPlayback(int interval, bool playback) → int
Starting Mic Testing (for Desktop OS)
startSpeakerDeviceTest(String filePath) → int
Starting Speaker Testing (for Desktop OS)
stopCameraDeviceTest() → void
Ending camera testing (for desktop OS)
stopMicDeviceTest() → void
Ending mic testing (for desktop OS)
stopSpeakerDeviceTest() → void
Ending speaker testing (for desktop OS)
switchCamera(bool frontCamera) → int
Switching to the front/rear camera (for mobile OS)
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited