V2TXLiveImage class

Image information for live streaming

Constructors

V2TXLiveImage({String? imageSrc, V2TXLiveImageType imageType = V2TXLiveImageType.v2TXLiveImageTypeBGRA32, int imageWidth = 0, int imageHeight = 0, int imageLength = 0})

Properties

hashCode int
The hash code for this object.
no setterinherited
imageHeight int
Field Meaning: Image height Default value: 0 (ignored when imageType is V2TXLiveImageTypeFile)
getter/setter pair
imageLength int
Field Meaning: Image data length in bytes
getter/setter pair
imageSrc String?
Field Meaning: Image source
getter/setter pair
imageType V2TXLiveImageType
Field Meaning: Image data type Default value: V2TXLiveImageTypeBGRA32
getter/setter pair
imageWidth int
Field Meaning: Image width Default value: 0 (ignored when imageType is V2TXLiveImageTypeFile)
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited