TXTrackInfo class
Track details.
Constructors
- TXTrackInfo(String name, int trackIndex, int trackType)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isExclusive ↔ bool
-
If true, only one track of this type can be selected at each time. If false, multiple tracks of this type can be selected at the same time.
getter/setter pair
- isInternal ↔ bool
-
Whether the current track is the internal original track.
getter/setter pair
- isSelected ↔ bool
-
Whether the current track is selected.
getter/setter pair
- name ↔ String
-
Track name.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- trackIndex ↔ int
-
Track index.
getter/setter pair
- trackType ↔ int
-
Track type.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromMap(
Map map) → TXTrackInfo - Construct from the Map returned by MethodChannel.
Constants
- TX_VOD_MEDIA_TRACK_TYPE_AUDIO → const int
- Audio track.
- TX_VOD_MEDIA_TRACK_TYPE_SUBTITLE → const int
- Subtitle track.
- TX_VOD_MEDIA_TRACK_TYPE_UNKNOW → const int
- Unknown.
- TX_VOD_MEDIA_TRACK_TYPE_VIDEO → const int
- Video track.