TXVodSubtitleData class
Properties
-
durationMs
↔ int?
-
Subtitle start time, which is the position of the video, in milliseconds.
getter/setter pair
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
startPositionMs
↔ int?
-
Subtitle duration, in milliseconds.
getter/setter pair
-
subtitleData
↔ String?
-
Subtitle content.
getter/setter pair
-
trackIndex
↔ int?
-
Track Index of the current subtitle track.
getter/setter pair
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited