VodGlobalChannel class

Global MethodChannel wrapper (download / pre-download / plugin methods).

Not bound to a playerId; invoked directly.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

invoke<T>(String method, [Map<String, dynamic>? args]) Future<T?>
invokeList(String method, [Map<String, dynamic>? args]) Future<List?>
invokeMap(String method, [Map<String, dynamic>? args]) Future<Map?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setMethodCallHandler(Future handler(MethodCall call)?) → void
Register a handler on this channel. Used by VodEventDispatcher during init.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

download VodGlobalChannel
Download / pre-download channel (used by TXVodDownloadController).
final
plugin VodGlobalChannel
Global plugin channel (used by SuperPlayerPlugin: License / cache dir / log).
final