TXAudioEffectManagerImpl class

Inheritance

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

destroy() → void
enableVoiceEarMonitor(bool enable) → void
Enabling In-Ear Monitoring
override
getMusicCurrentPosInMS(int id) → int
Getting the Playback Progress (ms) of Background Music
override
getMusicDurationInMS(String path) → int
Getting the Total Length (ms) of Background Music
override
getMusicTrackCount(int id) → int
Get the Number of Tracks of Background Music
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pausePlayMusic(int id) → void
Pausing Background Music
override
preloadMusic(AudioMusicParam musicParam) → void
Preload Background Music
override
resumePlayMusic(int id) → void
Resuming Background Music
override
seekMusicToPosInTime(int id, int pts) → void
Setting the Playback Progress (ms) of Background Music
override
setAllMusicVolume(int volume) → void
Setting the Local and Remote Playback Volume of Background Music
override
setMusicObserver(int musicId, TXMusicPlayObserver? observer) → void
Setting the Background Music Callback
override
setMusicPitch(int id, double pitch) → void
Adjusting the Pitch of Background Music
override
setMusicPlayoutVolume(int id, int volume) → void
Setting the Local Playback Volume of a Specific Music Track
override
setMusicPublishVolume(int id, int volume) → void
Setting the Remote Playback Volume of a Specific Music Track
override
setMusicScratchSpeedRate(int id, double scratchSpeedRate) → void
Adjust the Speed Change Effect of the Scratch Disc
override
setMusicSpeedRate(int id, double rate) → void
Changing the Speed of Background Music
override
setMusicTrack(int id, int trackIndex) → void
Specify the Playback Track of Background Music
override
setPreloadObserver(TXMusicPreloadObserver? observer) → void
Setting Music Preload Callback
override
setVoiceCaptureVolume(int volume) → void
Setting Speech Volume
override
setVoiceChangerType(TXVoiceChangerType type) → void
Setting Voice Changing Effects
override
setVoiceEarMonitorVolume(int volume) → void
Setting In-Ear Monitoring Volume
override
setVoicePitch(double pitch) → void
Setting Speech Pitch
override
setVoiceReverbType(TXVoiceReverbType type) → void
Setting Voice Reverb Effects
override
startPlayMusic(AudioMusicParam musicParam) → void
Starting Background Music
override
stopPlayMusic(int id) → void
Stopping Background Music
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited